@@ -112,7 +112,7 @@ class NotifyBark(NotifyBase):
     secure_protocol = "barks"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_bark"
+    setup_url = "https://appriseit.com/services/bark/"
 
     # Allows the user to specify the NotifyImageSize object; this is supported
     # through the webhook
@@ -445,7 +445,8 @@ class NotifyBark(NotifyBase):
                         )
                     )
 
-                    self.logger.debug(f"Response Details:\r\n{r.content}")
+                    self.logger.debug(
+                        "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                     # Mark our failure
                     has_error = True
