@@ -63,7 +63,7 @@ class NotifyBlueSky(NotifyBase):
     secure_protocol = ("bsky", "bluesky")
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_bluesky"
+    setup_url = "https://appriseit.com/services/bluesky/"
 
     # Support attachments
     attachment_support = True
@@ -610,7 +610,8 @@ class NotifyBlueSky(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Mark our failure
                 return (False, content)
