@@ -86,7 +86,7 @@ class NotifyBulkSMS(NotifyBase):
     secure_protocol = "bulksms"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_bulksms"
+    setup_url = "https://appriseit.com/services/bulksms/"
 
     # BulkSMS uses the http protocol with JSON requests
     notify_url = "https://api.bulksms.com/v1/messages"
@@ -387,7 +387,8 @@ class NotifyBulkSMS(NotifyBase):
                         )
                     )
 
-                    self.logger.debug(f"Response Details:\r\n{r.content}")
+                    self.logger.debug(
+                        "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                     # Mark our failure
                     has_error = True
