@@ -67,7 +67,7 @@ class NotifyClickSend(NotifyBase):
     secure_protocol = "clicksend"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_clicksend"
+    setup_url = "https://appriseit.com/services/clicksend/"
 
     # ClickSend uses the http protocol with JSON requests
     notify_url = "https://rest.clicksend.com/v3/sms/send"
@@ -231,7 +231,8 @@ class NotifyClickSend(NotifyBase):
                         )
                     )
 
-                    self.logger.debug(f"Response Details:\r\n{r.content}")
+                    self.logger.debug(
+                        "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                     # Mark our failure
                     has_error = True
