@@ -57,7 +57,7 @@ class NotifyEmby(NotifyBase):
     secure_protocol = "embys"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_emby"
+    setup_url = "https://appriseit.com/services/emby/"
 
     # By default Emby requires you to provide it a device id
     # The following was just a random uuid4 generated one.  There
@@ -225,7 +225,8 @@ class NotifyEmby(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
