@@ -59,7 +59,7 @@ class NotifyHomeAssistant(NotifyBase):
     default_insecure_port = 8123
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_homeassistant"
+    setup_url = "https://appriseit.com/services/homeassistant/"
 
     # Define object templates
     templates = (
@@ -217,7 +217,8 @@ class NotifyHomeAssistant(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
