@@ -380,7 +380,7 @@ class NotifyLametric(NotifyBase):
     request_rate_per_sec = 0.20
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_lametric"
+    setup_url = "https://appriseit.com/services/lametric/"
 
     # Lametric does have titles when creating a message
     title_maxlen = 0
@@ -856,7 +856,8 @@ class NotifyLametric(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
