@@ -78,7 +78,7 @@ class NotifyMacOSX(NotifyBase):
     protocol = "macosx"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_macosx"
+    setup_url = "https://appriseit.com/services/macosx/"
 
     # Allows the user to specify the NotifyImageSize object
     image_size = NotifyImageSize.XY_128
