@@ -110,7 +110,7 @@ class NotifyMailgun(NotifyBase):
     request_rate_per_sec = 0.20
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_mailgun"
+    setup_url = "https://appriseit.com/services/mailgun/"
 
     # Support attachments
     attachment_support = True
@@ -574,7 +574,8 @@ class NotifyMailgun(NotifyBase):
                         )
                     )
 
-                    self.logger.debug(f"Response Details:\r\n{r.content}")
+                    self.logger.debug(
+                        "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                     # Mark our failure
                     has_error = True
