@@ -157,7 +157,7 @@ class NotifyMatrix(NotifyBase):
     attachment_support = True
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_matrix"
+    setup_url = "https://appriseit.com/services/matrix/"
 
     # Allows the user to specify the NotifyImageSize object
     image_size = NotifyImageSize.XY_32
@@ -515,7 +515,8 @@ class NotifyMatrix(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
@@ -727,7 +728,7 @@ class NotifyMatrix(NotifyBase):
                 }
 
                 # Post our content
-                postokay, _response = self._fetch(
+                postokay, _, _ = self._fetch(
                     path, payload=image_payload)
                 if not postokay:
                     # Mark our failure
@@ -739,7 +740,7 @@ class NotifyMatrix(NotifyBase):
                     attachment["room_id"] = room_id
                     attachment["type"] = "m.room.message"
 
-                    postokay, _response = self._fetch(
+                    postokay, _, _ = self._fetch(
                         path, payload=attachment, method=method)
 
                     # Increment the transaction ID to avoid future messages
@@ -799,7 +800,7 @@ class NotifyMatrix(NotifyBase):
                 })
 
             # Post our content
-            postokay, _response = self._fetch(
+            postokay, _, _ = self._fetch(
                 path, payload=payload, method=method
             )
 
@@ -843,7 +844,8 @@ class NotifyMatrix(NotifyBase):
                 # unsuppored at this time
                 continue
 
-            postokay, response = self._fetch("/upload", attachment=attachment)
+            postokay, response, _ = \
+                self._fetch("/upload", attachment=attachment)
             if not (postokay and isinstance(response, dict)):
                 # Failed to perform upload
                 return False
@@ -907,7 +909,7 @@ class NotifyMatrix(NotifyBase):
             payload["password"] = self.password
 
         # Register
-        postokay, response = self._fetch(
+        postokay, response, _ = self._fetch(
             "/register", payload=payload, params=params
         )
         if not (postokay and isinstance(response, dict)):
@@ -979,7 +981,7 @@ class NotifyMatrix(NotifyBase):
             return False
 
         # Build our URL
-        postokay, response = self._fetch("/login", payload=payload)
+        postokay, response, _ = self._fetch("/login", payload=payload)
         if not (postokay and isinstance(response, dict)):
             # Failed to login
             return False
@@ -1022,7 +1024,7 @@ class NotifyMatrix(NotifyBase):
         payload = {}
 
         # Expire our token
-        postokay, response = self._fetch("/logout", payload=payload)
+        postokay, response, _ = self._fetch("/logout", payload=payload)
         if not postokay and response.get("errcode") != "M_UNKNOWN_TOKEN":
             # If we get here, the token was declared as having already
             # been expired.  The response looks like this:
@@ -1099,7 +1101,7 @@ class NotifyMatrix(NotifyBase):
             path = f"/join/{NotifyMatrix.quote(room_id)}"
 
             # Make our query
-            postokay, _ = self._fetch(path, payload=payload)
+            postokay, _, _ = self._fetch(path, payload=payload)
             if postokay:
                 # Cache our entry for fast access later
                 self.store.set(
@@ -1147,7 +1149,7 @@ class NotifyMatrix(NotifyBase):
         path = f"/join/{NotifyMatrix.quote(room)}"
 
         # Attempt to join the channel
-        postokay, response = self._fetch(path, payload=payload)
+        postokay, response, status_code = self._fetch(path, payload=payload)
         if postokay:
             # Cache our entry for fast access later
             self.store.set(
@@ -1160,8 +1162,22 @@ class NotifyMatrix(NotifyBase):
 
             return response.get("room_id")
 
-        # Try to create the channel
-        return self._room_create(room)
+        # Only attempt to create a room when the server clearly indicates
+        # the alias does not exist. A join can fail for many reasons, such as
+        # invite required, auth failure, or permissions, and in those cases
+        # auto-creating is both noisy and incorrect.
+        if (status_code == requests.codes.not_found
+                or response.get("errcode") == "M_NOT_FOUND"):
+            return self._room_create(room)
+
+        self.logger.warning(
+            "Could not join Matrix room alias %s (error=%s). "
+            "If this is a private room, ensure the user is invited or "
+            "already joined, or specify the room_id (!...).",
+            room,
+            status_code,
+        )
+        return None
 
     def _room_create(self, room):
         """Creates a matrix room and return it's room_id if successful
@@ -1201,7 +1217,8 @@ class NotifyMatrix(NotifyBase):
             "preset": "trusted_private_chat",
         }
 
-        postokay, response = self._fetch("/createRoom", payload=payload)
+        postokay, response, _ = \
+            self._fetch("/createRoom", payload=payload)
         if not postokay:
             # Failed to create channel
             # Typical responses:
@@ -1232,7 +1249,7 @@ class NotifyMatrix(NotifyBase):
             # No list is possible
             return []
 
-        postokay, response = self._fetch(
+        postokay, response, _ = self._fetch(
             "/joined_rooms", payload=None, method="GET"
         )
         if not postokay:
@@ -1276,7 +1293,7 @@ class NotifyMatrix(NotifyBase):
         room = "#{}:{}".format(result.group("room"), home_server)
 
         # Make our request
-        postokay, response = self._fetch(
+        postokay, response, _ = self._fetch(
             f"/directory/room/{NotifyMatrix.quote(room)}",
             payload=None,
             method="GET",
@@ -1299,10 +1316,11 @@ class NotifyMatrix(NotifyBase):
         """Wrapper to request.post() to manage it's response better and make
         the send() function cleaner and easier to maintain.
 
-        This function returns True if the _post was successful and False if it
-        wasn't.
+        This function always returns a 3-tuple:
+            (success, response, status_code)
 
-        this function returns the status code if url_override is used
+        The response is a dict when JSON is parseable, otherwise an empty dict.
+        The status_code defaults to 500 on local failures.
         """
 
         # Define our headers
@@ -1327,7 +1345,7 @@ class NotifyMatrix(NotifyBase):
 
             except MatrixDiscoveryException:
                 # Discovery failed; we're done
-                return (False, {})
+                return (False, {}, requests.codes.internal_server_error)
 
         # Default return status code
         status_code = requests.codes.internal_server_error
@@ -1379,7 +1397,7 @@ class NotifyMatrix(NotifyBase):
                     (
                         "POST"
                         if method == "POST"
-                        else (requests.put if method == "PUT" else "GET")
+                        else ("PUT" if method == "PUT" else "GET")
                     ),
                     url,
                     self.verify_certificate,
@@ -1450,10 +1468,7 @@ class NotifyMatrix(NotifyBase):
                     self.logger.debug(f"Response Details:\r\n{r.content}")
 
                     # Return; we're done
-                    return (
-                        False if not url_override else status_code,
-                        response,
-                    )
+                    return (False, response, status_code)
 
             except (AttributeError, TypeError, ValueError):
                 # This gets thrown if we can't parse our JSON Response
@@ -1461,8 +1476,10 @@ class NotifyMatrix(NotifyBase):
                 #  - TypeError = r.content is None
                 #  - AttributeError = r is None
                 self.logger.warning("Invalid response from Matrix server.")
-                self.logger.debug(f"Response Details:\r\n{r.content}")
-                return (False if not url_override else status_code, {})
+                self.logger.debug(
+                    "Response Details:\r\n%r",
+                    b"" if not r else (r.content or b""))
+                return (False, {}, status_code)
 
             except (requests.TooManyRedirects, requests.RequestException) as e:
                 self.logger.warning(
@@ -1471,7 +1488,7 @@ class NotifyMatrix(NotifyBase):
                 )
                 self.logger.debug("Socket Exception: %s", str(e))
                 # Return; we're done
-                return (False if not url_override else status_code, response)
+                return (False, response, status_code)
 
             except OSError as e:
                 self.logger.warning(
@@ -1480,12 +1497,12 @@ class NotifyMatrix(NotifyBase):
                     )
                 )
                 self.logger.debug("I/O Exception: %s", str(e))
-                return (False if not url_override else status_code, {})
+                return (False, {}, status_code)
 
-            return (True if not url_override else status_code, response)
+            return (True, response, status_code)
 
         # If we get here, we ran out of retries
-        return (False if not url_override else status_code, {})
+        return (False, {}, status_code)
 
     def __del__(self):
         """Ensure we relinquish our token."""
@@ -1721,7 +1738,7 @@ class NotifyMatrix(NotifyBase):
                 port=("" if not self.port else f":{self.port}"),
             )
 
-        code, wk_response = self._fetch(
+        _, response, status_code = self._fetch(
             None, method="GET", url_override=verify_url
         )
 
@@ -1735,7 +1752,7 @@ class NotifyMatrix(NotifyBase):
         #     }
         # }
 
-        if code == requests.codes.not_found:
+        if status_code == requests.codes.not_found:
             # This is an acceptable response; we're done
             self.logger.debug(
                 "Matrix Well-Known Base URI not found at %s", verify_url
@@ -1754,15 +1771,16 @@ class NotifyMatrix(NotifyBase):
             )
             return ""
 
-        elif code != requests.codes.ok:
+        elif status_code != requests.codes.ok:
             # We're done early as we couldn't load the results
             msg = "Matrix Well-Known Base URI Discovery Failed"
             self.logger.warning(
-                "%s - %s returned error code: %d", msg, verify_url, code
+                    "%s - %s returned error code: %d",
+                    msg, verify_url, status_code,
             )
-            raise MatrixDiscoveryException(msg, error_code=code)
+            raise MatrixDiscoveryException(msg, error_code=status_code)
 
-        if not wk_response:
+        if not response:
             # This is an acceptable response; we simply do nothing
             self.logger.debug(
                 "Matrix Well-Known Base URI not defined %s", verify_url
@@ -1785,13 +1803,13 @@ class NotifyMatrix(NotifyBase):
         # Parse our m.homeserver information
         #
         try:
-            base_url = wk_response["m.homeserver"]["base_url"].rstrip("/")
+            base_url = response["m.homeserver"]["base_url"].rstrip("/")
             results = NotifyBase.parse_url(base_url, verify_host=True)
 
         except (AttributeError, TypeError, KeyError):
             # AttributeError: result wasn't a string (rstrip failed)
-            # TypeError     : wk_response wasn't a dictionary
-            # KeyError      : wk_response not to standards
+            # TypeError     : response wasn't a dictionary
+            # KeyError      : response not to standards
             results = None
 
         if not results:
@@ -1799,7 +1817,7 @@ class NotifyMatrix(NotifyBase):
             self.logger.warning(
                 "%s - m.homeserver payload is missing or invalid: %s",
                 msg,
-                str(wk_response),
+                str(response),
             )
             raise MatrixDiscoveryException(msg)
 
@@ -1809,31 +1827,32 @@ class NotifyMatrix(NotifyBase):
         #
         verify_url = f"{base_url}/_matrix/client/versions"
         # Post our content
-        code, _response = self._fetch(
+        _, _, status_code = self._fetch(
             None, method="GET", url_override=verify_url
         )
-        if code != requests.codes.ok:
+        if status_code != requests.codes.ok:
             # We're done early as we couldn't load the results
             msg = "Matrix Well-Known Base URI Discovery Verification Failed"
             self.logger.warning(
-                "%s - %s returned error code: %d", msg, verify_url, code
+                    "%s - %s returned error code: %d",
+                    msg, verify_url, status_code,
             )
-            raise MatrixDiscoveryException(msg, error_code=code)
+            raise MatrixDiscoveryException(msg, error_code=status_code)
 
         #
         # Phase 2: Handle m.identity_server IF defined
         #
-        if "m.identity_server" in wk_response:
+        if "m.identity_server" in response:
             try:
-                identity_url = wk_response["m.identity_server"][
+                identity_url = response["m.identity_server"][
                     "base_url"
                 ].rstrip("/")
                 results = NotifyBase.parse_url(identity_url, verify_host=True)
 
             except (AttributeError, TypeError, KeyError):
                 # AttributeError: result wasn't a string (rstrip failed)
-                # TypeError     : wk_response wasn't a dictionary
-                # KeyError      : wk_response not to standards
+                # TypeError     : response wasn't a dictionary
+                # KeyError      : response not to standards
                 results = None
 
             if not results:
@@ -1841,7 +1860,7 @@ class NotifyMatrix(NotifyBase):
                 self.logger.warning(
                     "%s - m.identity_server payload is missing or invalid: %s",
                     msg,
-                    str(wk_response),
+                    str(response),
                 )
                 raise MatrixDiscoveryException(msg)
 
@@ -1851,16 +1870,17 @@ class NotifyMatrix(NotifyBase):
             verify_url = f"{identity_url}/_matrix/identity/v2"
 
             # Post our content
-            code, _response = self._fetch(
+            _postokay, _, status_code = self._fetch(
                 None, method="GET", url_override=verify_url
             )
-            if code != requests.codes.ok:
+            if status_code != requests.codes.ok:
                 # We're done early as we couldn't load the results
                 msg = "Matrix Well-Known Identity URI Discovery Failed"
                 self.logger.warning(
-                    "%s - %s returned error code: %d", msg, verify_url, code
+                    "%s - %s returned error code: %d",
+                    msg, verify_url, status_code,
                 )
-                raise MatrixDiscoveryException(msg, error_code=code)
+                raise MatrixDiscoveryException(msg, error_code=status_code)
 
             # Update our cache
             self.store.set(
