@@ -99,7 +99,7 @@ class NotifyMQTT(NotifyBase):
     secure_protocol = "mqtts"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_mqtt"
+    setup_url = "https://appriseit.com/services/mqtt/"
 
     # MQTT does not have a title
     title_maxlen = 0
