@@ -158,7 +158,7 @@ class NotifyNtfy(NotifyBase):
     secure_protocol = "ntfys"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_ntfy"
+    setup_url = "https://appriseit.com/services/ntfy/"
 
     # Default upstream/cloud host if none is defined
     cloud_notify_url = "https://ntfy.sh"
@@ -697,7 +697,8 @@ class NotifyNtfy(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 return False, response
 
