@@ -40,6 +40,7 @@
 #
 from datetime import datetime, timedelta
 import json
+import logging
 from uuid import uuid4
 
 import requests
@@ -49,6 +50,7 @@ from ..common import NotifyFormat, NotifyType, PersistentStoreMode
 from ..locale import gettext_lazy as _
 from ..url import PrivacyMode
 from ..utils.parse import is_email, parse_emails, validate_regex
+from ..utils.sanitize import sanitize_payload
 from .base import NotifyBase
 
 
@@ -69,7 +71,7 @@ class NotifyOffice365(NotifyBase):
     request_rate_per_sec = 0.20
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_office365"
+    setup_url = "https://appriseit.com/services/office365/"
 
     # URL to Microsoft Graph Server
     graph_url = "https://graph.microsoft.com"
@@ -813,12 +815,17 @@ class NotifyOffice365(NotifyBase):
         content = {}
 
         # Some Debug Logging
-        self.logger.debug(
-            "Office 365 %s URL:"
-            f" {url} (cert_verify={self.verify_certificate})",
-            method,
-        )
-        self.logger.debug(f"Office 365 Payload: {payload}")
+        if self.logger.isEnabledFor(logging.DEBUG):
+            # Due to attachments; output can be quite heavy and io intensive
+            # To accommodate this, we only show our debug payload information
+            # if required.
+            self.logger.debug(
+                "Office 365 %s URL:"
+                f" {url} (cert_verify={self.verify_certificate})",
+                method,
+            )
+            self.logger.debug(
+                "Office 365 Payload: %s", sanitize_payload(payload))
 
         # Always call throttle before any remote server i/o is made
         self.throttle()
@@ -903,7 +910,8 @@ class NotifyOffice365(NotifyBase):
                 #  }
                 # }
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Mark our failure
                 return (False, content)
