@@ -101,7 +101,7 @@ class NotifyPagerDuty(NotifyBase):
     secure_protocol = "pagerduty"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_pagerduty"
+    setup_url = "https://appriseit.com/services/pagerduty/"
 
     # We don't support titles for Pager Duty notifications
     title_maxlen = 0
@@ -374,7 +374,7 @@ class NotifyPagerDuty(NotifyBase):
         if image_url:
             payload["images"] = [{
                 "src": image_url,
-                "alt": notify_type,
+                "alt": notify_type.value,
             }]
 
         if self.details:
@@ -420,7 +420,8 @@ class NotifyPagerDuty(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
