@@ -57,7 +57,7 @@ class NotifyPushed(NotifyBase):
     secure_protocol = "pushed"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_pushed"
+    setup_url = "https://appriseit.com/services/pushed/"
 
     # Pushed uses the http protocol with JSON requests
     notify_url = "https://api.pushed.co/1/push"
@@ -289,7 +289,8 @@ class NotifyPushed(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
