@@ -85,7 +85,7 @@ class NotifyRocketChat(NotifyBase):
     secure_protocol = "rockets"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_rocketchat"
+    setup_url = "https://appriseit.com/services/rocketchat/"
 
     # Allows the user to specify the NotifyImageSize object; this is supported
     # through the webhook
@@ -576,7 +576,8 @@ class NotifyRocketChat(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
