@@ -54,7 +54,7 @@ class NotifyServerChan(NotifyBase):
     secure_protocol = "schan"
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_serverchan"
+    setup_url = "https://appriseit.com/services/serverchan/"
 
     # ServerChan API
     notify_url = "https://sctapi.ftqq.com/{token}.send"
@@ -113,6 +113,8 @@ class NotifyServerChan(NotifyBase):
             r = requests.post(
                 notify_url,
                 data=payload,
+                verify=self.verify_certificate,
+                timeout=self.request_timeout,
             )
 
             if r.status_code != requests.codes.ok:
@@ -128,7 +130,8 @@ class NotifyServerChan(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
                 return False
 
             else:
