@@ -104,7 +104,7 @@ class NotifyTwilio(NotifyBase):
     validity_period = 14400
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_twilio"
+    setup_url = "https://appriseit.com/services/twilio/"
 
     # Twilio uses the http protocol with JSON message requests
     notify_sms_url = (
@@ -477,7 +477,8 @@ class NotifyTwilio(NotifyBase):
                         )
                     )
 
-                    self.logger.debug(f"Response Details:\r\n{r.content}")
+                    self.logger.debug(
+                        "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                     # Mark our failure
                     has_error = True
