@@ -91,7 +91,7 @@ class NotifyWebexTeams(NotifyBase):
     secure_protocol = ("wxteams", "webex")
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_wxteams"
+    setup_url = "https://appriseit.com/services/wxteams/"
 
     # Webex Teams uses the http protocol with JSON requests
     notify_url = "https://api.ciscospark.com/v1/webhooks/incoming/"
@@ -196,7 +196,8 @@ class NotifyWebexTeams(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 return False
 
