@@ -93,7 +93,7 @@ class NotifyWorkflows(NotifyBase):
     secure_protocol = ("workflow", "workflows")
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_workflows"
+    setup_url = "https://appriseit.com/services/workflows/"
 
     # Allows the user to specify the NotifyImageSize object
     image_size = NotifyImageSize.XY_32
@@ -308,7 +308,7 @@ class NotifyWorkflows(NotifyBase):
                 "type": "Image",
                 "url": image_url,
                 "height": "32px",
-                "altText": notify_type,
+                "altText": notify_type.value,
             })
 
         if title:
@@ -473,7 +473,8 @@ class NotifyWorkflows(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # We failed
                 return False
