@@ -58,7 +58,7 @@ class NotifyXBMC(NotifyBase):
     secure_protocol = (xbmc_secure_protocol, kodi_secure_protocol)
 
     # A URL that takes you to the setup/help of the specific protocol
-    setup_url = "https://github.com/caronc/apprise/wiki/Notify_kodi"
+    setup_url = "https://appriseit.com/services/kodi/"
 
     # Disable throttle rate for XBMC/KODI requests since they are normally
     # local anyway
@@ -288,7 +288,8 @@ class NotifyXBMC(NotifyBase):
                     )
                 )
 
-                self.logger.debug(f"Response Details:\r\n{r.content}")
+                self.logger.debug(
+                    "Response Details:\r\n%r", (r.content or b"")[:2000])
 
                 # Return; we're done
                 return False
